Tutorials
=========

The easiest way to use sumo is through the command line interface.
A broad range of functionality is available. See the individual pages
for each command (below) for more details.

A new Sumo tutorial for CASTEP users is being developed
`here <https://github.com/ajjackson/castep-sumo-tutorial/blob/master/castep-sumo.org>`_.

.. toctree::
   :maxdepth: 2

   sumo-kgen
   sumo-dosplot
   sumo-bandplot
   sumo-bandstats
   sumo-optplot
   sumo-phonon-bandplot

   customising-plots
